import{I as f,_ as v}from"./ProviderDetails.vue_vue_type_style_index_0_lang-ClXR5oFa.js";import{I}from"./ItemsListing-D6AMqIYc.js";import{c as a,E as _}from"./index-CxiRlsCY.js";import{d as h,r as p,w as b,o as w,a0 as y,b as k,e as r,H as E,D as n,I as l,F as D}from"./lucide-C2DU1LFb.js";import"./Toolbar-MwYpbj3t.js";import"./vuetify-RelkxOq-.js";import"./marquee_text_sync-BtOjTSaq.js";import"./vue-router-BgJK_hRC.js";import"./MediaItemThumb-C7OhU3lK.js";import"./ProviderIcon.vue_vue_type_style_index_0_lang-C17dV9_V.js";import"./Container-CwfZ2VgM.js";import"./index-kQIztB-E.js";import"./ListItem-DzUpG5Dm.js";import"./Button-DBt8j7D4.js";import"./vue-i18n-DySrp6mW.js";import"./utils-CDN07tui.js";import"./userPreferences-ln7cf3P6.js";import"./NowPlayingBadge.vue_vue_type_style_index_0_lang-D7lqdhVg.js";import"./PanelviewItemCompact-Cjl_ij1h.js";import"./qrcode-DSFhiIp2.js";import"./marked-C0Rlrcoy.js";import"./color-BTziYnFN.js";import"./vueuse-DIaEWNCo.js";/* empty css            */import"./swiper-Jy9GbtzK.js";const W=h({__name:"PodcastDetails",props:{itemId:{},provider:{}},setup(d){const t=d,i=p(!1),e=p(),u=async function(){e.value=await a.getPodcast(t.itemId,t.provider)};b(()=>t.itemId,o=>{o&&u()},{immediate:!0}),w(()=>{const o=a.subscribe(_.MEDIA_ITEM_UPDATED,s=>{const m=s.data;e.value?.uri==m.uri&&(e.value=m,i.value=!0)});y(o)});const c=async function(o){return await a.getPodcastEpisodes(t.itemId,t.provider)};return(o,s)=>(r(),k(D,null,[E(f,{item:e.value},null,8,["item"]),e.value?(r(),n(I,{key:0,itemtype:"podcastepisodes","parent-item":e.value,"show-provider":!1,"show-library":!1,"show-favorites-only-filter":!1,"show-track-number":!0,"show-refresh-button":!0,"load-items":c,"sort-keys":["position","position_desc","name","duration","duration_desc"],"update-available":i.value,title:o.$t("podcast_episodes"),"allow-key-hooks":!0,path:`podcast.${t.itemId}.${t.provider}`,"restore-state":!0,"no-server-side-sorting":!0},null,8,["parent-item","update-available","title","path"])):l("",!0),e.value?(r(),n(v,{key:1,"item-details":e.value},null,8,["item-details"])):l("",!0)],64))}});export{W as default};
