import{c as d}from"./utils-CDN07tui.js";import{a2 as p,a3 as i,a4 as m}from"./reka-ui-GpbaI08z.js";import{d as l,D as o,e as c,E as n,h as u,ad as _,u as s,A as f}from"./lucide-C2DU1LFb.js";import{v}from"./vueuse-DIaEWNCo.js";const y=l({__name:"Avatar",props:{class:{}},setup(e){const a=e;return(t,r)=>(c(),o(s(p),{"data-slot":"avatar",class:_(s(d)("relative flex size-8 shrink-0 overflow-hidden rounded-full",a.class))},{default:n(()=>[u(t.$slots,"default")]),_:3},8,["class"]))}}),C=l({__name:"AvatarFallback",props:{delayMs:{},asChild:{type:Boolean},as:{},class:{}},setup(e){const a=e,t=v(a,"class");return(r,h)=>(c(),o(s(i),f({"data-slot":"avatar-fallback"},s(t),{class:s(d)("bg-muted flex size-full items-center justify-center rounded-full",a.class)}),{default:n(()=>[u(r.$slots,"default")]),_:3},16,["class"]))}}),$=l({__name:"AvatarImage",props:{src:{},referrerPolicy:{},crossOrigin:{},asChild:{type:Boolean},as:{}},setup(e){const a=e;return(t,r)=>(c(),o(s(m),f({"data-slot":"avatar-image"},a,{class:"aspect-square size-full"}),{default:n(()=>[u(t.$slots,"default")]),_:3},16))}});export{y as _,$ as a,C as b};
