.user-name-box[data-v-8cbf5f8f],.user-name-box[data-v-9638370d]{background:rgba(var(--v-theme-error),.08);border-left:3px solid rgb(var(--v-theme-error));padding:12px 16px;border-radius:4px;font-weight:500;font-size:.938rem}
