import{c as i}from"./index-CxiRlsCY.js";import{d as c}from"./vuetify-RelkxOq-.js";import{d as u,c as m,b as o,e as r,n as l,D as d,u as t,f as v}from"./lucide-C2DU1LFb.js";const f=["title"],h=["innerHTML"],y=["title"],p=["innerHTML"],g=["title"],k=["innerHTML"],w=u({__name:"ProviderIcon",props:{domain:{},size:{},dark:{type:Boolean},monochrome:{type:Boolean}},setup(n){const a=n,e=m(()=>{if(a.domain in i.providers)return i.providers[a.domain].domain;if(a.domain in i.providerManifests)return a.domain});return(s,M)=>(r(),o("div",{style:l(`width:${n.size}px;margin-left:10px;margin-right:10px;content-align:center`)},[n.domain&&n.domain=="library"?(r(),d(c,{key:0,size:n.size,icon:"mdi-bookshelf",title:s.$t("item_in_library")},null,8,["size","title"])):a.monochrome&&e.value&&t(i).providerManifests[e.value].icon_svg_monochrome?(r(),o("div",{key:1,class:"d-flex align-center justify-center align-content-center justify-content-center",style:l(`width: ${n.size}px;height: ${n.size}px;${s.$vuetify.theme.current.dark?"":"filter: invert(1);"}`),title:t(i).providerManifests[e.value].name},[v("div",{class:"svg-wrapper",innerHTML:t(i).providerManifests[e.value].icon_svg_monochrome},null,8,h)],12,f)):s.$vuetify.theme.current.dark&&e.value&&t(i).providerManifests[e.value].icon_svg_dark?(r(),o("div",{key:2,class:"d-flex align-center justify-center align-content-center justify-content-center",style:l(`width: ${n.size}px;height: ${n.size}px;`),title:t(i).providerManifests[e.value].name},[v("div",{class:"svg-wrapper",innerHTML:t(i).providerManifests[e.value].icon_svg_dark},null,8,p)],12,y)):e.value&&t(i).providerManifests[e.value].icon_svg?(r(),o("div",{key:3,class:"d-flex align-center justify-center align-content-center justify-content-center",style:l(`width: ${n.size}px;height: ${n.size}px;`),title:t(i).providerManifests[e.value].name},[v("div",{class:"svg-wrapper",innerHTML:t(i).providerManifests[e.value].icon_svg},null,8,k)],12,g)):e.value&&t(i).providerManifests[e.value].icon?(r(),d(c,{key:4,size:n.size,icon:"mdi-"+t(i).providerManifests[e.value].icon,title:t(i).providerManifests[e.value].name,dark:s.$vuetify.theme.current.dark},null,8,["size","icon","title","dark"])):(r(),d(c,{key:5,size:n.size,dark:s.$vuetify.theme.current.dark,icon:"mdi-playlist-play"},null,8,["size","dark"]))],4))}});export{w as _};
