.config-field[data-v-36dfaf6b]{flex:1;min-width:0}.config-divider[data-v-36dfaf6b]{padding:8px 0}.divider-label[data-v-36dfaf6b]{display:block;margin-top:12px;font-weight:600;font-size:.875rem}.config-alert[data-v-36dfaf6b],.action-btn[data-v-36dfaf6b]{margin:8px 0}.config-slider-wrapper[data-v-36dfaf6b]{display:flex;flex-direction:column;gap:8px}.config-slider-label[data-v-36dfaf6b]{font-size:.875rem;color:rgba(var(--v-theme-on-surface),.7);margin-bottom:0}.config-slider-block[data-v-36dfaf6b]{display:flex;flex-direction:row;align-items:center;gap:8px}.config-slider-input[data-v-36dfaf6b]{flex-shrink:0}@media(min-width:601px){.config-slider-wrapper[data-v-36dfaf6b]{flex-direction:row;align-items:center;gap:12px}.config-slider-label[data-v-36dfaf6b]{flex-shrink:0;margin-bottom:0}.config-slider-block[data-v-36dfaf6b]{flex:1}}.dsp-config[data-v-36dfaf6b]{display:flex;align-items:center;gap:16px;padding:8px 0}.dsp-status[data-v-36dfaf6b]{font-size:.875rem;color:rgba(var(--v-theme-on-surface),.7)}.config-section[data-v-5a9dd3b6]{margin-bottom:16px}.config-entry[data-v-5a9dd3b6]{display:flex;align-items:flex-start;gap:8px;margin-bottom:8px}.config-entry[data-v-5a9dd3b6]:last-child{margin-bottom:0}.config-entry:has(.v-checkbox)+.config-entry[data-v-5a9dd3b6]:has(.v-text-field),.config-entry:has(.v-checkbox)+.config-entry[data-v-5a9dd3b6]:has(.v-select),.config-entry:has(.v-checkbox)+.config-entry[data-v-5a9dd3b6]:has(.v-slider),.config-entry:has(.v-checkbox)+.config-entry[data-v-5a9dd3b6]:has(.v-combobox){margin-top:16px}.help-btn[data-v-5a9dd3b6]{flex-shrink:0;margin-top:8px;opacity:.6;transition:opacity .2s ease;height:36px}.help-btn[data-v-5a9dd3b6]:hover{opacity:1}@media(min-width:601px){.config-entry:has(.config-slider-wrapper) .help-btn[data-v-5a9dd3b6]{margin-top:0;align-self:center}}@media(max-width:600px){.config-entry:has(.config-slider-wrapper) .help-btn[data-v-5a9dd3b6]{align-self:flex-start;margin-top:0}}.config-panels[data-v-5a9dd3b6]{margin-top:16px}.config-panel[data-v-5a9dd3b6]{margin-bottom:8px;border:1px solid rgba(var(--v-theme-on-surface),.12);border-radius:8px!important;overflow:hidden}.config-panel[data-v-5a9dd3b6]:before{display:none}.config-panel-title[data-v-5a9dd3b6]{min-height:52px;padding:14px 20px;background:rgba(var(--v-theme-primary),.08)}.config-panel-title .v-icon[data-v-5a9dd3b6]{color:rgb(var(--v-theme-primary))}.panel-title-text[data-v-5a9dd3b6]{font-size:1.1rem;font-weight:600;color:rgb(var(--v-theme-primary))}.config-panel[data-v-5a9dd3b6] .v-expansion-panel-text__wrapper{padding:0}.config-panel-content[data-v-5a9dd3b6]{padding:16px 20px 20px;border-top:1px solid rgba(var(--v-theme-on-surface),.08)}.config-actions[data-v-5a9dd3b6]{display:flex;flex-direction:column;gap:12px;margin-top:24px;padding-top:16px}
