import{c as r}from"./utils-CDN07tui.js";import{d as e,b as o,e as c,ad as n,u as d,h as l}from"./lucide-C2DU1LFb.js";const m=e({__name:"CardDescription",props:{class:{}},setup(s){const a=s;return(t,p)=>(c(),o("p",{"data-slot":"card-description",class:n(d(r)("text-muted-foreground text-sm",a.class))},[l(t.$slots,"default")],2))}}),_=e({__name:"CardHeader",props:{class:{}},setup(s){const a=s;return(t,p)=>(c(),o("div",{"data-slot":"card-header",class:n(d(r)("@container/card-header grid auto-rows-min grid-rows-[auto_auto] items-start gap-1.5 px-6 has-data-[slot=card-action]:grid-cols-[1fr_auto] [.border-b]:pb-6",a.class))},[l(t.$slots,"default")],2))}}),f=e({__name:"CardTitle",props:{class:{}},setup(s){const a=s;return(t,p)=>(c(),o("h3",{"data-slot":"card-title",class:n(d(r)("leading-none font-semibold",a.class))},[l(t.$slots,"default")],2))}});export{_,f as a,m as b};
