import{u as g,X as y,Y as h,Z as B,p as w,_ as x,$ as b,a0 as D}from"./reka-ui-GpbaI08z.js";import{d,D as i,e as l,E as r,h as c,J as P,K as M,A as p,u as e,H as $}from"./lucide-C2DU1LFb.js";import{c as m}from"./utils-CDN07tui.js";import{v}from"./vueuse-DIaEWNCo.js";const S=d({__name:"DropdownMenu",props:{defaultOpen:{type:Boolean},open:{type:Boolean},dir:{},modal:{type:Boolean}},emits:["update:open"],setup(t,{emit:a}){const n=g(t,a);return(u,f)=>(l(),i(e(y),p({"data-slot":"dropdown-menu"},e(n)),{default:r(_=>[c(u.$slots,"default",P(M(_)))]),_:3},16))}}),F=d({inheritAttrs:!1,__name:"DropdownMenuContent",props:{forceMount:{type:Boolean},loop:{type:Boolean},side:{},sideOffset:{default:4},sideFlip:{type:Boolean},align:{},alignOffset:{},alignFlip:{type:Boolean},avoidCollisions:{type:Boolean},collisionBoundary:{},collisionPadding:{},arrowPadding:{},sticky:{},hideWhenDetached:{type:Boolean},positionStrategy:{},updatePositionStrategy:{},disableUpdateOnLayoutShift:{type:Boolean},prioritizePosition:{type:Boolean},reference:{},asChild:{type:Boolean},as:{},class:{default:void 0}},emits:["escapeKeyDown","pointerDownOutside","focusOutside","interactOutside","closeAutoFocus"],setup(t,{emit:a}){const o=t,s=a,n=v(o,"class"),u=g(n,s);return(f,_)=>(l(),i(e(B),null,{default:r(()=>[$(e(h),p({"data-slot":"dropdown-menu-content"},{...f.$attrs,...e(u)},{class:e(m)("bg-popover text-popover-foreground data-[state=open]:animate-in data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=open]:fade-in-0 data-[state=closed]:zoom-out-95 data-[state=open]:zoom-in-95 data-[side=bottom]:slide-in-from-top-2 data-[side=left]:slide-in-from-right-2 data-[side=right]:slide-in-from-left-2 data-[side=top]:slide-in-from-bottom-2 z-50 max-h-(--reka-dropdown-menu-content-available-height) min-w-[8rem] origin-(--reka-dropdown-menu-content-transform-origin) overflow-x-hidden overflow-y-auto rounded-md border p-1 shadow-md",o.class)}),{default:r(()=>[c(f.$slots,"default")]),_:3},16,["class"])]),_:3}))}}),A=d({__name:"DropdownMenuItem",props:{disabled:{type:Boolean},textValue:{},asChild:{type:Boolean},as:{},class:{default:void 0},inset:{type:Boolean,default:!1},variant:{default:"default"}},setup(t){const a=t,o=v(a,"inset","variant","class"),s=w(o);return(n,u)=>(l(),i(e(x),p({"data-slot":"dropdown-menu-item","data-inset":t.inset?"":void 0,"data-variant":t.variant},e(s),{class:e(m)("focus:bg-accent focus:text-accent-foreground data-[variant=destructive]:text-destructive data-[variant=destructive]:focus:bg-destructive/10 dark:data-[variant=destructive]:focus:bg-destructive/20 data-[variant=destructive]:focus:text-destructive data-[variant=destructive]:*:[svg]:!text-destructive [&_svg:not([class*='text-'])]:text-muted-foreground relative flex cursor-default items-center gap-3 cursor-pointer rounded-sm px-2 py-2 text-sm outline-hidden select-none data-[disabled]:pointer-events-none data-[disabled]:opacity-50 data-[inset]:pl-8 [&_svg]:pointer-events-none [&_svg]:shrink-0 [&_svg:not([class*='size-'])]:size-4",a.class)}),{default:r(()=>[c(n.$slots,"default")]),_:3},16,["data-inset","data-variant","class"]))}}),E=d({__name:"DropdownMenuSeparator",props:{asChild:{type:Boolean},as:{},class:{}},setup(t){const a=t,o=v(a,"class");return(s,n)=>(l(),i(e(b),p({"data-slot":"dropdown-menu-separator"},e(o),{class:e(m)("bg-border -mx-1 my-1 h-px",a.class)}),null,16,["class"]))}}),I=d({__name:"DropdownMenuTrigger",props:{disabled:{type:Boolean},asChild:{type:Boolean},as:{}},setup(t){const o=w(t);return(s,n)=>(l(),i(e(D),p({"data-slot":"dropdown-menu-trigger"},e(o)),{default:r(()=>[c(s.$slots,"default")]),_:3},16))}});export{S as _,I as a,F as b,E as c,A as d};
