import{y as b,h as k,z as h,M as m,_ as C}from"./index-CxiRlsCY.js";import{d as p,o as B,D as o,e as t,al as f,u as n,E as a,h as V,b as c,ad as $,H as r,f as v,I as u,a1 as R,F as x,M,$ as A}from"./lucide-C2DU1LFb.js";import{P as I}from"./PanelviewItemCompact-Cjl_ij1h.js";import{_ as P}from"./ProviderIcon.vue_vue_type_style_index_0_lang-C17dV9_V.js";import{B as T,n as g,o as z,s as E}from"./vuetify-RelkxOq-.js";const N=p({__name:"Carousel",setup(e){return B(()=>{document.documentElement.style.setProperty("--swiper-navigation-color","primary")}),(d,l)=>{const w=f("swiper");return t(),o(w,{"slides-per-view":n(b)(d.$vuetify.display.width)+.5,"free-mode":!0,navigation:!1,mousewheel:{forceToAxis:!0,releaseOnEdges:!0}},{default:a(()=>[V(d.$slots,"default")]),_:3},8,["slides-per-view"])}}}),O={class:"mr-3"},D={key:0},W={class:"carousel-wrapper"},F=p({__name:"WidgetRow",props:{widgetRow:{},editMode:{type:Boolean},showProviderOnCover:{type:Boolean}},emits:["update:settings"],setup(e,{emit:d}){const l=d;return(w,s)=>{const y=f("swiper-slide");return t(),c("div",{class:$(`widget-row ${e.widgetRow.settings&&!e.widgetRow.settings.enabled?"disabled":""}`)},[r(T,{class:"header",color:"transparent"},{title:a(()=>[v("span",O,R(e.widgetRow.title),1),e.widgetRow.subtitle&&n(k)("bp6")?(t(),o(z,{key:0,inline:"",outlined:"",text:e.widgetRow.subtitle,density:"compact",size:"small"},null,8,["text"])):u("",!0)]),append:a(()=>[e.editMode&&e.widgetRow.settings?(t(),c("div",D,[e.widgetRow.settings.position!==0?(t(),o(g,{key:0,icon:"mdi-chevron-up",class:"enabled",onClick:s[0]||(s[0]=i=>l("update:settings",{...e.widgetRow.settings,position:e.widgetRow.settings.position-1}))})):u("",!0),r(g,{icon:"mdi-chevron-down",onClick:s[1]||(s[1]=i=>l("update:settings",{...e.widgetRow.settings,position:e.widgetRow.settings.position+1}))}),r(g,{icon:e.widgetRow.settings.enabled?"mdi-checkbox-marked":"mdi-checkbox-blank-outline",onClick:s[2]||(s[2]=i=>l("update:settings",{...e.widgetRow.settings,enabled:!e.widgetRow.settings.enabled}))},null,8,["icon"])])):e.widgetRow.provider?(t(),o(P,{key:1,domain:e.widgetRow.provider,size:24},null,8,["domain"])):u("",!0)]),_:1}),v("div",W,[e.widgetRow.items.length>0?(t(),o(N,{key:0},{default:a(()=>[(t(!0),c(x,null,M(e.widgetRow.items,i=>(t(),o(y,{key:i.uri},{default:a(()=>[r(I,{item:i,"show-provider-on-cover":e.showProviderOnCover,"permanent-overlay":![n(m).ALBUM,n(m).TRACK,n(m).RADIO].includes(i.media_type),"is-available":n(h)(i),disabled:e.editMode},null,8,["item","show-provider-on-cover","permanent-overlay","is-available","disabled"])]),_:2},1024))),128))]),_:1})):(t(),o(E,{key:1},{default:a(()=>[A(R(w.$t("no_content")),1)]),_:1}))])],2)}}}),j=C(F,[["__scopeId","data-v-a88771f6"]]);export{j as W};
