.player-volume-container[data-v-8f38c6dc]{position:relative;display:flex;align-items:center;gap:8px;touch-action:pan-x;user-select:none;-webkit-user-select:none;-webkit-tap-highlight-color:transparent}.player-volume-container.disabled[data-v-8f38c6dc]{opacity:.4;cursor:not-allowed;pointer-events:none}.player-volume-container.not-powered[data-v-8f38c6dc]{opacity:.5}.volume-prepend[data-v-8f38c6dc],.volume-append[data-v-8f38c6dc]{flex-shrink:0;display:flex;align-items:center;overflow:visible}.volume-prepend[data-v-8f38c6dc]{margin-right:4px}.volume-append[data-v-8f38c6dc]{margin-left:4px}.volume-icon-btn[data-v-8f38c6dc]{background:none;border:none;padding:4px;cursor:pointer;opacity:.7;transition:opacity .15s ease;display:flex;align-items:center;justify-content:center;color:inherit}.volume-icon-btn[data-v-8f38c6dc]:hover{opacity:1}.volume-icon-btn[data-v-8f38c6dc]:active{opacity:.5}.volume-icon-btn[data-v-8f38c6dc]:disabled{opacity:.3;cursor:not-allowed}@media(pointer:coarse){.volume-slider[data-v-8f38c6dc]{pointer-events:none}}.player-volume-container[data-v-8f38c6dc] [data-slot=slider-track]{background-color:rgba(var(--v-theme-on-surface),.15)!important}.v-theme--dark .player-volume-container[data-v-8f38c6dc] [data-slot=slider-track]{background-color:rgba(var(--v-theme-on-surface),.2)!important}.volumesliderrow[data-v-951e032a]{margin-top:0;padding-top:0;padding-bottom:0;height:40px;min-height:40px}.volumesliderrow[data-v-951e032a] .v-list-item__content{height:40px;min-height:40px;overflow:visible!important;align-content:center}.heading[data-v-951e032a]{margin-bottom:5px;height:35px}.volumecaption[data-v-951e032a]{width:34px;text-align:right;margin-right:-20px}.expandbtn[data-v-951e032a]{margin-right:-12px}.powerbtn[data-v-951e032a]{right:8px}.volumesliderrow[data-v-951e032a] .v-list-item__prepend{width:40px;margin-left:-10px}.volumesliderrow[data-v-951e032a] .v-list-item__append{width:20px}.checkbox[data-v-951e032a]{margin-right:-5px;width:25px;margin-top:-30px;height:22px!important;min-height:22px!important;display:unset}.syncbtn[data-v-951e032a]{margin-right:-32px;height:25px!important;padding-bottom:20px}.panel-item-details[data-v-7b6504e0]{width:100%;margin:0!important;padding:0!important;min-height:72px}.panel-item-details[data-v-7b6504e0] .v-list-item__content{display:flex;flex-direction:column;justify-content:center;min-height:60px}.volumesliderrow[data-v-7b6504e0]{margin-top:0;padding-top:0;padding-bottom:0;height:24px;min-height:24px}.volumecaption[data-v-7b6504e0]{width:25px;text-align:right;margin-right:0}.volumesliderrow[data-v-7b6504e0] .v-list-item__prepend{width:40px;margin-left:-25px}.volumesliderrow[data-v-7b6504e0] .v-expansion-panel-text__wrapper{padding:0}.player-media-thumb[data-v-7b6504e0]{margin-right:10px}.media-thumb[data-v-7b6504e0]{width:60px;height:60px;border-radius:4px;background-color:rgba(var(--v-theme-on-surface),.08)}.icon-thumb[data-v-7b6504e0]{width:60px;height:60px;border-radius:4px;background-color:rgba(var(--v-theme-on-surface),.08);display:flex;align-items:center;justify-content:center}.media-thumb[data-v-7b6504e0]{width:55px;height:55px;border-radius:4px;background-color:rgba(var(--v-theme-on-surface),.08)}.icon-thumb[data-v-7b6504e0]{width:55px;height:55px;margin-top:5px;border-radius:4px;background-color:rgba(var(--v-theme-on-surface),.08);display:inline-table}.panel-item[data-v-7b6504e0]{border-style:ridge;border-width:thin;border-color:rgba(var(--v-theme-on-surface),.12);padding:5px 8px;background-color:rgba(var(--v-theme-primary),.04);opacity:1;transition:opacity .4s ease-in-out;border-radius:6px;margin:5px 0 8px;height:100%;width:auto}.panel-item-idle[data-v-7b6504e0]{opacity:.8}.panel-item-off[data-v-7b6504e0]{opacity:.6}.panel-item-selected[data-v-7b6504e0]{border-color:rgba(var(--v-theme-primary),.6);background-color:rgba(var(--v-theme-primary),.3)}.player-command-btn[data-v-7b6504e0]{width:35px;min-width:35px;margin-left:5px}.group-badge[data-v-7b6504e0] .v-badge__badge{font-size:10px;height:14px;min-width:14px;padding:0 4px}
