import{C as w}from"./Container-CwfZ2VgM.js";import{_ as L}from"./ProviderIcon.vue_vue_type_style_index_0_lang-C17dV9_V.js";import{c as r,_ as S}from"./index-CxiRlsCY.js";import{u as z}from"./vue-router-BgJK_hRC.js";import{b as B,a as D,c as _,W as g,X as C,d as l,_ as v}from"./vuetify-RelkxOq-.js";import{d as E,r as N,c as T,o as F,D as m,e as a,E as e,H as o,b as h,M as k,F as x,$ as c,a1 as d,I as A,u as y}from"./lucide-C2DU1LFb.js";import{u as H}from"./vue-i18n-DySrp6mW.js";import"./index-kQIztB-E.js";import"./qrcode-DSFhiIp2.js";import"./marked-C0Rlrcoy.js";import"./color-BTziYnFN.js";import"./vueuse-DIaEWNCo.js";/* empty css            */import"./swiper-Jy9GbtzK.js";const R=E({__name:"SystemConfig",setup(W){const u=z(),{t:i}=H(),p=N([]),I=[{domain:"logging",name:"settings.system_logging",description:"settings.system_logging_description",icon:"mdi-text-box-search",route:"/settings/serverlogs"}],V=T(()=>[...p.value].sort((t,n)=>r.providerManifests[t.domain].name.localeCompare(r.providerManifests[n.domain].name))),$=t=>{const n=i(`settings.core_module.${t.domain}.name`);return n!==`settings.core_module.${t.domain}.name`?n:r.providerManifests[t.domain].name},b=t=>{const n=i(`settings.core_module.${t.domain}.description`);return n!==`settings.core_module.${t.domain}.description`?n:r.providerManifests[t.domain].description},f=function(t){t.route?u.push(t.route):u.push(`/settings/editcore/${t.domain}`)};return F(async()=>{p.value=await r.getCoreConfigs()}),(t,n)=>(a(),m(w,{variant:"comfortable",class:"settings-overview"},{default:e(()=>[o(D,{class:"settings-main-card"},{default:e(()=>[o(B,{class:"settings-list"},{default:e(()=>[(a(!0),h(x,null,k(V.value,s=>(a(),m(_,{key:s.domain,ripple:!0,class:"settings-list-item",onClick:M=>f(s)},{prepend:e(()=>[o(v,{color:"blue",size:"48"},{default:e(()=>[o(L,{domain:s.domain,size:24,color:"white"},null,8,["domain"])]),_:2},1024)]),append:e(()=>[s.last_error?(a(),m(l,{key:0,color:"red",icon:"mdi-alert-circle",class:"mr-2",title:s.last_error},null,8,["title"])):A("",!0),o(l,{icon:"mdi-chevron-right"})]),default:e(()=>[o(g,{class:"text-h6"},{default:e(()=>[c(d($(s)),1)]),_:2},1024),o(C,null,{default:e(()=>[c(d(b(s)),1)]),_:2},1024)]),_:2},1032,["onClick"]))),128)),(a(),h(x,null,k(I,s=>o(_,{key:s.domain,ripple:!0,class:"settings-list-item",onClick:M=>f(s)},{prepend:e(()=>[o(v,{color:"purple",size:"48"},{default:e(()=>[o(l,{icon:s.icon,size:"24",color:"white"},null,8,["icon"])]),_:2},1024)]),append:e(()=>[o(l,{icon:"mdi-chevron-right"})]),default:e(()=>[o(g,{class:"text-h6"},{default:e(()=>[c(d(y(i)(s.name)),1)]),_:2},1024),o(C,null,{default:e(()=>[c(d(y(i)(s.description)),1)]),_:2},1024)]),_:2},1032,["onClick"])),64))]),_:1})]),_:1})]),_:1}))}}),se=S(R,[["__scopeId","data-v-fe538fe8"]]);export{se as default};
