.breadcrumb-container[data-v-e24b2804]{display:flex;align-items:center;flex-wrap:wrap;gap:4px;min-width:0;max-width:100%}.breadcrumb-segment[data-v-e24b2804]{display:flex;align-items:center;gap:4px;min-width:0}.breadcrumb-link[data-v-e24b2804]{background:none;border:none;color:inherit;cursor:pointer;text-decoration:underline;font-family:inherit;font-size:inherit;padding:0;margin:0;white-space:nowrap;overflow:hidden;text-overflow:ellipsis;max-width:200px}.breadcrumb-link[data-v-e24b2804]:hover{opacity:.7}.breadcrumb-text[data-v-e24b2804]{color:inherit;white-space:nowrap;overflow:hidden;text-overflow:ellipsis;max-width:200px}.breadcrumb-separator[data-v-e24b2804]{opacity:.5;margin:0 2px;flex-shrink:0}.breadcrumb-container:has(.breadcrumb-segment:nth-child(4)) .breadcrumb-link[data-v-e24b2804],.breadcrumb-container:has(.breadcrumb-segment:nth-child(4)) .breadcrumb-text[data-v-e24b2804]{font-size:.9em}.breadcrumb-container:has(.breadcrumb-segment:nth-child(5)) .breadcrumb-link[data-v-e24b2804],.breadcrumb-container:has(.breadcrumb-segment:nth-child(5)) .breadcrumb-text[data-v-e24b2804]{font-size:.85em;max-width:150px}.breadcrumb-container:has(.breadcrumb-segment:nth-child(6)) .breadcrumb-link[data-v-e24b2804],.breadcrumb-container:has(.breadcrumb-segment:nth-child(6)) .breadcrumb-text[data-v-e24b2804]{font-size:.8em;max-width:120px}
